@@ -86,10 +86,45 @@ def check_ckeditor_settings(app_configs, **kwargs) -> list:  # pragma: no cover
                 obj="settings.TEXT_ADDITIONAL_ATTRIBUTES",
             )
         )
+    if check_ckeditor_cms_plugin_settings(settings):
+        warnings.append(
+            Warning(
+                "The CKEDITOR_SETTINGS toolbar setting has changed: Instead of 'cmsplugins' use 'CMSPlugins'.",
+                hint="Replace 'cmsplugins' by 'CMSPlugins' in CKEDITOR_SETTINGS.",
+                id="text.W003",
+            )
+        )
 
     return warnings
 
 
+def check_ckeditor_cms_plugin_settings(settings: object) -> list:  # pragma: no cover
+    def recursive_replace(config_list: list, old: str, new: str):
+        """Replace target string in toolbar lists and return True if any change occurred."""
+        changed = False
+        for index, item in enumerate(config_list):
+            if isinstance(item, list):
+                changed = changed or recursive_replace(item, old, new)
+            elif isinstance(item, dict) and "items" in item:
+                changed = changed or recursive_replace(item["items"], old, new)
+            elif item == old:
+                config_list[index] = new
+                changed = True
+        return changed
+
+    if hasattr(settings, "CKEDITOR_SETTINGS"):
+        ckeditor_settings = settings.CKEDITOR_SETTINGS
+        change_required = False
+
+        for key, value in ckeditor_settings.items():
+            if "toolbar" in key and isinstance(value, list):
+                change_required = change_required or recursive_replace(
+                    ckeditor_settings[key], "cmsplugins", "CMSPlugins"
+                )
+        return change_required
+    return False
+
+
 def check_no_cms_config(app_configs, **kwargs) -> list:  # pragma: no cover
     from django.conf import settings
 
