@@ -48,6 +48,7 @@ from cms.utils.placeholder import get_placeholder_conf
 from cms.utils.urlutils import admin_reverse
 
 from . import settings
+from .editors import get_editor_config
 from .forms import ActionTokenValidationForm, RenderPluginForm, TextForm
 from .html import render_dynamic_attributes
 from .models import Text, _MAX_RTE_LENGTH
@@ -62,7 +63,10 @@ from .utils import (
     random_comment_exempt,
     replace_plugin_tags,
 )
-from .widgets import TextEditorWidget, rte_config
+from .widgets import TextEditorWidget
+
+
+rte_config = get_editor_config()
 
 
 def post_add_plugin(operation, **kwargs):
@@ -252,7 +256,11 @@ class TextPlugin(CMSPluginBase):
                 body_css_classes=self._get_body_css_classes_from_parent_plugins(plugin),
                 add_admin_css=True,
             )
-        else:
+        elif (
+            request.GET.get("placeholder_id")
+            and request.GET.get("plugin_language")
+            and request.GET.get("plugin_position")
+        ):
             widget = TextEditorWidget(
                 installed_plugins=plugins,
                 pk=None,
@@ -266,6 +274,10 @@ class TextPlugin(CMSPluginBase):
                 revert_on_cancel=False,
                 body_css_classes="",
             )
+        else:
+            from django.forms.widgets import Textarea
+
+            widget = Textarea()
         return widget
 
     def _get_body_css_classes_from_parent_plugins(
@@ -623,7 +635,7 @@ class TextPlugin(CMSPluginBase):
             page=page,
         )
         child_plugins = (get_plugin(name) for name in child_plugin_types)
-        template = getattr(self.page, "template", None)
+        template = getattr(page, "template", None)
 
         modules = get_placeholder_conf("plugin_modules", plugin.placeholder.slot, template, default={})
         names = get_placeholder_conf("plugin_labels", plugin.placeholder.slot, template, default={})
