@@ -3,7 +3,6 @@ from urllib.parse import urlparse, urlunparse
 from django.apps import apps
 from django.forms import forms
 from django.http import QueryDict
-from django.templatetags.static import static
 from django.utils.functional import cached_property
 from django.utils.translation import gettext_lazy as _
 
@@ -12,8 +11,12 @@ from cms.toolbar_base import CMSToolbar
 from cms.toolbar_pool import toolbar_pool
 
 from . import settings
+from .editors import get_editor_config
 from .utils import get_cancel_url, get_messages_url, get_render_plugin_url
-from .widgets import TextEditorWidget, get_url_endpoint, rte_config
+from .widgets import TextEditorWidget, get_url_endpoint
+
+
+rte_config = get_editor_config()
 
 
 class IconButton(Button):
@@ -34,12 +37,7 @@ class InlineEditingToolbar(CMSToolbar):
                     if self.inline_editing
                     else ("djangocms_text/css/cms.text.css",),
                 },
-                js=(
-                    static("djangocms_text/bundles/bundle.editor.min.js"),
-                    *(static(js) for js in rte_config.js),
-                )
-                if self.inline_editing
-                else (),
+                js=("djangocms_text/bundles/bundle.editor.min.js", *rte_config.js) if self.inline_editing else (),
             )
         return forms.Media()
 
