@@ -13,10 +13,16 @@ import nh3
 from lxml import etree
 from lxml.etree import Element
 
-from . import settings
+from djangocms_text import settings
 
 
 dyn_attr_pattern = re.compile(r"<[^>]*data-cms-[^>]*>")
+cms_additional_attributes = {
+    "a": {"href", "target", "rel"},
+    "cms-plugin": {"id", "title", "name", "alt", "render-plugin", "type"},
+    "*": {"style", "class", "role"},
+}
+cms_generic_attribute_prefixes = {"data-", "aria-"}
 
 
 class NH3Parser:
@@ -40,22 +46,31 @@ class NH3Parser:
         additional_attributes: Optional[dict[str, set[str]]] = None,
         generic_attribute_prefixes: Optional[set[str]] = None,
     ):
+        if additional_attributes is None:
+            additional_attributes = cms_additional_attributes
+        if generic_attribute_prefixes is None:
+            generic_attribute_prefixes = cms_generic_attribute_prefixes
+
         self.ALLOWED_TAGS: set[str] = deepcopy(nh3.ALLOWED_TAGS)
         self.ALLOWED_ATTRIBUTES: dict[str, set[str]] = deepcopy(nh3.ALLOWED_ATTRIBUTES)
-        self.generic_attribute_prefixes: set[str] = generic_attribute_prefixes or set()
-        additional_attributes = {
-            **settings.TEXT_ADDITIONAL_ATTRIBUTES,
-            **(additional_attributes or {}),
-        }
+        self.ALLOWED_URL_SCHEMES: set[str] = deepcopy(nh3.ALLOWED_URL_SCHEMES) | set(settings.TEXT_ADDITIONAL_PROTOCOLS)
+        self.generic_attribute_prefixes: set[str] = generic_attribute_prefixes
+
+        for tag, attributes in settings.TEXT_ADDITIONAL_ATTRIBUTES.items():
+            if tag in additional_attributes:
+                additional_attributes[tag] = additional_attributes[tag] | attributes
+            else:
+                additional_attributes[tag] = attributes
+
         if additional_attributes:
-            self.ALLOWED_TAGS |= set(additional_attributes.keys())
+            self.ALLOWED_TAGS |= {key for key in additional_attributes.keys() if key != "*"}
             for tag, attributes in additional_attributes.items():
                 self.ALLOWED_ATTRIBUTES[tag] = self.ALLOWED_ATTRIBUTES.get(tag, set()) | attributes
 
     def __call__(self) -> dict[str, Union[dict[str, set[str]], set[str], None]]:
         """
         Return a dictionary containing the attributes, tags, generic_attribute_prefixes, and link_rel values for
-        immidiate passing to the nh3.clean function.
+        immediate passing to the nh3.clean function.
 
         :return: A dictionary with the following keys:
             - "attributes": A dictionary containing the allowed attributes setting.
@@ -71,34 +86,32 @@ class NH3Parser:
             "attributes": self.ALLOWED_ATTRIBUTES,
             "tags": self.ALLOWED_TAGS,
             "generic_attribute_prefixes": self.generic_attribute_prefixes,
+            "url_schemes": self.ALLOWED_URL_SCHEMES,
             "link_rel": None,
         }
 
 
-cms_parser: NH3Parser = NH3Parser(
-    additional_attributes={
-        "a": {"href", "target", "rel"},
-        "cms-plugin": {"id", "title", "name", "alt", "render-plugin", "type"},
-        "*": {"style", "class"},
-    },
-    generic_attribute_prefixes={"data-"},
-)
+cms_parser: NH3Parser = NH3Parser()
 #: An instance of NH3Parser with the default configuration for CMS text content.
 
 
-def clean_html(data: str, full: bool = False, cleaner: NH3Parser = cms_parser) -> str:
+def clean_html(data: str, full: Optional[bool] = None, cleaner: NH3Parser = None) -> str:
     """
     Cleans HTML from XSS vulnerabilities using nh3
     If full is False, only the contents inside <body> will be returned (without
     the <body> tags).
     """
 
-    if full is not False:
+    if settings.TEXT_HTML_SANITIZE is False:
+        return data
+
+    if full is not None:
         warnings.warn(
             "full argument is deprecated and will be removed",
             category=DeprecationWarning,
             stacklevel=2,
         )
+    cleaner = cleaner or cms_parser
     return nh3.clean(data, **cleaner())
 
 
@@ -151,7 +164,7 @@ def get_data_from_db(models: dict, admin_objects: bool = False) -> dict:
     return result
 
 
-def dynamic_href(elem: Element, obj: models.Model, attr: str) -> None:
+def dynamic_href(elem: Element, obj: models.Model, attr: str, edit_mode: bool = False) -> None:
     """
     Modifies an element's attribute to create a dynamic hyperlink based on the provided model object.
     In case the object has a "get_absolute_url" method, and it returns a non-empty value, the attribute of the
@@ -173,15 +186,14 @@ def dynamic_href(elem: Element, obj: models.Model, attr: str) -> None:
     target_value = ""
     if hasattr(obj, "get_absolute_url"):
         target_value = obj.get_absolute_url()
-        if target_value:
-            elem.attrib[attr] = obj.get_absolute_url()
+        elem.attrib[attr] = target_value or "#"
     if not target_value:
         elem.attrib["data-cms-error"] = "ref-not-found"
-        if elem.tag == "a":
+        if elem.tag == "a" and not edit_mode:
             elem.tag = "span"
 
 
-def dynamic_src(elem: Element, obj: models.Model, attr: str) -> None:
+def dynamic_src(elem: Element, obj: models.Model, attr: str, edit_mode: bool = False) -> None:
     """
     This method modifies the provided element by setting the value of the specified attribute based on the provided
     object. If the object has a "get_absolute_url" method, and it returns a non-empty value, the attribute of the
@@ -221,7 +233,6 @@ def render_dynamic_attributes(dyn_html: str, admin_objects: bool = False, remove
     - str: The updated HTML content with dynamic attributes
 
     """
-
     if not dyn_attr_pattern.search(dyn_html):
         # No dynamic attributes found, skip processing the html tree
         return dyn_html
@@ -256,7 +267,7 @@ def render_dynamic_attributes(dyn_html: str, admin_objects: bool = False, remove
                     obj = from_db[model.strip()][int(pk.strip())]
                 except (KeyError, ValueError):
                     obj = None
-                dynamic_attr_pool[attr](elem, obj, target_attr)
+                dynamic_attr_pool[attr](elem, obj, target_attr, edit_mode=admin_objects)
                 if remove_attr:
                     # Remove dynamic attribute's source for public view
                     del elem.attrib[attr]
